@@ -97,7 +97,19 @@ BACKGROUND_TASK_MAX_EXECUTION_TIME = 300
 INTERACTIVE_TASK_MAX_EXECUTION_TIME = 120
 SCHEDULED_TASK_MAX_EXECUTION_TIME = 60 * 60 * 12
 RESULT_SENDER_MAX_RETRIES = 5
+RESULT_SENDER_WAIT_GRACE_SECONDS = 90
 
 MAX_RETRY_TIME_GENERIC_SECONDS = 15 * 60
 MAX_RETRY_TIME_MAINTENANCE_SECONDS = 3 * 60 * 60
 MAX_RETRY_DELAY_TIME_SECONDS = 5 * 60
+
+DELAY_ON_CONNECT_EXCEPTION_SECONDS = 5
+
+ORDINAL_SUFFIX = {
+    1: 'st',
+    2: 'nd',
+    3: 'rd',
+    11: 'th',
+    12: 'th',
+    13: 'th',
+}
